trigger_check_name

Function trigger_check_name 

pub fn trigger_check_name(table: &str, expr: &str) -> String
Generate a deterministic trigger name for a trigger-enforced check.

Trigger names are scoped to a table in Postgres, but we still include the table name and a stable hash of the expression for readability and determinism.