ColumnNameRef

Struct ColumnNameRef 

pub struct ColumnNameRef(/* private fields */);
The name of a column or column alias.

Used in SELECT, INSERT, UPDATE SET, and RETURNING clauses.

Implementations

Source

impl ColumnNameRef

pub const fn from_str(raw: &str) -> &Self

Transparently reinterprets the string slice as a strongly-typed ColumnNameRef

pub const fn from_static(raw: &'static str) -> &'static Self

Transparently reinterprets the static string slice as a strongly-typed ColumnNameRef

pub fn into_owned(self: Box<ColumnNameRef>) -> ColumnName

Converts a Box<ColumnNameRef> into a ColumnName without copying or allocating

pub const fn as_str(&self) -> &str

Provides access to the underlying value as a string slice.